@@ -124,6 +124,7 @@ class SynopticWidget(QtWidgets.QWidget):
                     text = texta + self._modelNames + textb
             view.setHtml(text, base_url)
 
+        self.view = view
         return view
 
     def _handle_subscriptions(self, models):
@@ -184,6 +185,19 @@ class SynopticWidget(QtWidgets.QWidget):
         else:
             self.js.evaluate("synoptic.hideTooltip();")
 
+    def keyPressEvent(self, e):
+        super().keyPressEvent(e)
+        # show inspector window
+        if e.key() == QtCore.Qt.Key_F12:
+            DEBUG_PORT = '5588'
+            DEBUG_URL = f'[http://127.0.0.1](http://127.0.0.1/):{DEBUG_PORT}'
+            os.environ['QTWEBENGINE_REMOTE_DEBUGGING'] = DEBUG_PORT
+            self.inspector = QWebEngineView()
+            self.inspector.setWindowTitle('Web Inspector')
+            self.inspector.load(QtCore.QUrl(DEBUG_URL))
+            self.view.page().setDevToolsPage(self.inspector.page())
+            self.inspector.show()
+
     # # # 'Public' API # # #
 
     def zoom_to(self, kind, name):
